@@ -1,21 +1,15 @@
 import { Op } from 'sequelize';
-import config from 'config';
 import { chunk, omit, omitBy } from 'lodash';
 import { VISIBILITY_STATUSES } from '@tamanu/constants';
 import { NOTE_RECORD_TYPES } from '@tamanu/constants/notes';
 import { InvalidParameterError } from '@tamanu/shared/errors';
 import { log } from '@tamanu/shared/services/logging';
-import { refreshChildRecordsForSync } from '@tamanu/shared/utils/refreshChildRecordsForSync';
 
 const BULK_CREATE_BATCH_SIZE = 100;
 
 // These ones just need a patientId switched over.
 // Models included here will just have their patientId field
 // redirected to the new patient and that's all.
-
-// IMPORTANT: Any models here that have child records, please add the logic to handle them
-// in:
-// - updateDependentRecordsForResync function in this file
 export const simpleUpdateModels = [
   'Encounter',
   'PatientAllergy',
@@ -39,15 +33,10 @@ export const simpleUpdateModels = [
 // These ones need a little more attention.
 // Models in this array will be ignored by the automatic pass
 // so that they can be handled elsewhere.
-
-// IMPORTANT: Any models here that have child records, please add the logic to handle them
-// in:
-// - updateDependentRecordsForResync function in this file
 export const specificUpdateModels = [
   'Patient',
   'PatientAdditionalData',
   'PatientProgramRegistration',
-  'PatientProgramRegistrationCondition',
   'PatientBirthData',
   'PatientDeathData',
   'Note',
@@ -239,10 +228,9 @@ export async function mergePatientProgramRegistrations(models, keepPatientId, un
   const results = [];
 
   for (const unwantedRegistration of existingUnwantedRegistrations) {
-    // Move to keep patient and reset isMostRecent to false
+    // Move to keep patient
     await unwantedRegistration.update({
       patientId: keepPatientId,
-      isMostRecent: false,
     });
 
     // Soft delete the registration
@@ -253,36 +241,6 @@ export async function mergePatientProgramRegistrations(models, keepPatientId, un
   return results;
 }
 
-export async function mergePatientProgramRegistrationConditions(
-  models,
-  keepPatientId,
-  unwantedPatientId,
-) {
-  const existingUnwantedRegistrationConditions =
-    await models.PatientProgramRegistrationCondition.findAll({
-      where: { patientId: unwantedPatientId },
-    });
-
-  if (!existingUnwantedRegistrationConditions.length) {
-    return [];
-  }
-
-  const results = [];
-
-  for (const unwantedCondition of existingUnwantedRegistrationConditions) {
-    // Move to keep patient
-    await unwantedCondition.update({
-      patientId: keepPatientId,
-    });
-
-    // Soft delete the registration
-    await unwantedCondition.destroy();
-    results.push(unwantedCondition);
-  }
-
-  return results;
-}
-
 export async function mergePatientFieldValues(models, keepPatientId, unwantedPatientId) {
   const existingUnwantedFieldValues = await models.PatientFieldValue.findAll({
     where: { patientId: unwantedPatientId },
@@ -359,49 +317,7 @@ export async function reconcilePatientFacilities(models, keepPatientId, unwanted
   return newPatientFacilities;
 }
 
-export async function refreshMultiChildRecordsForSync(model, records) {
-  for (const record of records) {
-    await refreshChildRecordsForSync(model, record.id);
-  }
-}
-
-/**
- * Due to the generic cascade deletion hook, when the unwanted patient deletion is synced down to facility,
- * all dependent records that are not updated as part of this transaction will also be soft deleted in facility.
- * Hence, we need to update the dependent records of unwanted patient in this transaction, so that they are not soft deleted.
- * @param {*} models
- * @param {*} unwantedPatientId
- */
-async function updateDependentRecordsForResync(models, unwantedPatientId) {
-  // Encounters
-  const encounters = await models.Encounter.findAll({
-    where: { patientId: unwantedPatientId },
-    attributes: ['id'],
-  });
-  await refreshMultiChildRecordsForSync(models.Encounter, encounters);
-
-  // Patient Care Plans
-  const patientCarePlans = await models.PatientCarePlan.findAll({
-    where: { patientId: unwantedPatientId },
-    attributes: ['id'],
-  });
-  await refreshMultiChildRecordsForSync(models.PatientCarePlan, patientCarePlans);
-
-  // Patient Death Data
-  const patientDeathDataRecords = await models.PatientDeathData.findAll({
-    where: { patientId: unwantedPatientId },
-    attributes: ['id'],
-  });
-  await refreshMultiChildRecordsForSync(models.PatientDeathData, patientDeathDataRecords);
-}
-
-export async function mergePatient(
-  models,
-  keepPatientId,
-  unwantedPatientId,
-  updateDependentRecordsForResyncEnabled = config.patientMerge
-    .updateDependentRecordsForResyncEnabled,
-) {
+export async function mergePatient(models, keepPatientId, unwantedPatientId) {
   const { sequelize } = models.Patient;
 
   if (keepPatientId === unwantedPatientId) {
@@ -437,11 +353,6 @@ export async function mergePatient(
       visibilityStatus: VISIBILITY_STATUSES.MERGED,
     });
 
-    // See the function's documentation for more details on why this is needed
-    if (updateDependentRecordsForResyncEnabled) {
-      await updateDependentRecordsForResync(models, unwantedPatientId);
-    }
-
     updates.Patient = 2;
 
     // update associated records
@@ -501,13 +412,6 @@ export async function mergePatient(
       updates.PatientProgramRegistration = patientProgramRegistrationUpdates.length;
     }
 
-    const patientProgramRegistrationConditionUpdates =
-      await mergePatientProgramRegistrationConditions(models, keepPatientId, unwantedPatientId);
-    if (patientProgramRegistrationConditionUpdates.length > 0) {
-      updates.PatientProgramRegistrationCondition =
-        patientProgramRegistrationConditionUpdates.length;
-    }
-
     // Merge notes - these don't have a patient_id due to their polymorphic FK setup
     // so need to be handled slightly differently.
     const notesMerged = await mergeRecordsForModel(
